/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2000 - 2010, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.authordoclet.pipeline;

import org.jboss.authordoclet.Context;
import org.jboss.authordoclet.processor.Processor;

import java.util.logging.Logger;
import java.io.File;
import java.io.InputStreamReader;
import java.io.BufferedReader;

/**
 *
 */
public abstract class Pipeline<IN, OUT> {

    final private Logger log = Logger.getLogger(Pipeline.class.getName());

    final private Context context = new Context();

    public Context getContext() {
        return context;
    }

    protected void resetContext() {
        getContext().clear();
    }

    public OUT execute(IN input) {
        log.info("Executing: " + getClass().getName());
        
        resetContext();
        OUT output = null;
        for (Processor<IN, OUT> processor : getProcessors()) {
            output = processor.process(input, getContext());
        }
        return output;
    }

    protected void prepareOutputFile(File file, boolean overwrite) throws Exception {
        if (file.exists() && !overwrite) {
            String input = "";
            while (!input.toLowerCase().equals("y")) {
                System.out.print("Overwrite output file '" + file.getAbsolutePath() + "'? (Y/n): ");
                input = (new BufferedReader(new InputStreamReader(System.in))).readLine();
                if (input.length() == 0) {
                    input = "y";
                }
                if (input.equals("n")) {
                    System.out.println("Aborting...");
                    return;
                }
            }
        } else {
            file.createNewFile();
        }
    }

    public abstract Processor<IN, OUT>[] getProcessors();
}
