/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2000 - 2010, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.authordoclet.test;

import org.jboss.authordoclet.Constants;
import org.jboss.authordoclet.anchor.Anchor;
import org.jboss.authordoclet.anchor.AnchorOption;
import org.jboss.authordoclet.processor.xhtml.JavadocCitationProcessor;
import org.jboss.authordoclet.reader.PlaintextReader;
import org.jboss.authordoclet.reader.javacode.JavacodeRawReader;
import org.jboss.authordoclet.reader.javacode.JavacodeReader;
import org.jboss.authordoclet.reader.javadoc.JavadocReader;
import org.jboss.authordoclet.reader.xml.XMLReader;
import org.jboss.authordoclet.test.util.DocletTest;
import static org.testng.Assert.assertEquals;
import org.testng.annotations.Test;
import org.w3c.dom.Element;

/**
 *
 */
public class ReaderSelectionTests extends DocletTest {

    @Test
    public void selectReader() throws Exception {
        
        JavadocCitationProcessor processor = new JavadocCitationProcessor(getRootDoc());

        Element element = xmlDocument.createElement("a");
        element.setAttribute(Constants.ATTR_TYPE, Constants.TYPE_CITATION);

        element.setAttribute(Constants.ATTR_ADDRESS, "javadoc://com.myorg.MyClass");
        Anchor citation = new Anchor(element);
        assertEquals(processor.getReader(citation).getClass(), JavadocReader.class);

        element.setAttribute(Constants.ATTR_ADDRESS, "javacode://com.myorg.MyClass");
        citation = new Anchor(element);
        assertEquals(processor.getReader(citation).getClass(), JavacodeReader.class);

        element.setAttribute(Constants.ATTR_ADDRESS, "file://com/myorg/MyClass.java");
        citation = new Anchor(element);
        assertEquals(processor.getReader(citation).getClass(), JavacodeRawReader.class);

        element.setAttribute(Constants.ATTR_ADDRESS, "file://foo/bar.txt");
        citation = new Anchor(element);
        assertEquals(processor.getReader(citation).getClass(), PlaintextReader.class);
        element.setAttribute(Constants.ATTR_ADDRESS, "file://foo/bar.xhtml");

        citation = new Anchor(element);
        assertEquals(processor.getReader(citation).getClass(), XMLReader.class);

        element.setAttribute(Constants.ATTR_OPTIONS, AnchorOption.OPT_READER + ": " + PlaintextReader.class.getName());
        citation = new Anchor(element);
        assertEquals(processor.getReader(citation).getClass(), PlaintextReader.class);
    }
}
